@@ -45,7 +45,7 @@ Options:
 
 """
 
-__version__ = '0.0.11'
+__version__ = '0.0.12'
 
 
 from getpass import getpass
@@ -176,7 +176,8 @@ class Client(object):
     root = fromstring('<data>%s</data>' % (data, ))
     pastes = root.getchildren()
     print (
-      '%10s %4s %2s %3s %-25s %s' % ('key', 'min', 'pr', 'hit', 'url', 'title')
+      '\n%10s %4s %2s %3s %-25s %s' %
+      ('key', 'min', 'pr', 'hit', 'url', 'title')
     )
     now = time()
     for paste in pastes:
